Struct core::num::NonZeroUsize [] [src]

pub struct NonZeroUsize(_);
🔬 This is a nightly-only experimental API. (nonzero #49137)

An integer that is known not to equal zero.

This may enable some memory layout optimization such as:

use std::mem::size_of;
assert_eq!(size_of::<Option<std::num::NonZeroU32>>(), size_of::<u32>());Run

Methods

impl NonZeroUsize
[src]

[src]

🔬 This is a nightly-only experimental API. (nonzero #49137)

Create a non-zero without checking the value.

Safety

The value must not be zero.

[src]

🔬 This is a nightly-only experimental API. (nonzero #49137)

Create a non-zero if the given value is not zero.

[src]

🔬 This is a nightly-only experimental API. (nonzero #49137)

Returns the value as a primitive type.